import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import BaseUploadServer, DocsDoc
from vkbottle_types.responses.base import (
    BaseGetUploadServerResponse,
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.docs import *  # noqa: F401,F403  # type: ignore


class DocsCategory(BaseCategory):
    async def add(
        self,
        doc_id: int,
        owner_id: int,
        access_key: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `docs.add()`

        :param doc_id: Document ID.
        :param owner_id: ID of the user or community that owns the document. Use a negative value to designate a community ID.
        :param access_key: Access key. This parameter is required if 'access_key' was returned with the document's data.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.add", params)
        model = DocsAddResponse
        return model(**response).response

    async def delete(
        self,
        doc_id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `docs.delete()`

        :param doc_id: Document ID.
        :param owner_id: ID of the user or community that owns the document. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.delete", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit(
        self,
        doc_id: int,
        title: str,
        owner_id: typing.Optional[int] = None,
        tags: typing.Optional[typing.List[str]] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `docs.edit()`

        :param doc_id: Document ID.
        :param title: Document title.
        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        :param tags: Document tags.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.edit", params)
        model = BaseOkResponse
        return model(**response).response

    async def get(
        self,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        return_tags: typing.Optional[bool] = None,
        type: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> DocsGetResponseModel:
        """Method `docs.get()`

        :param count: Number of documents to return. By default, all documents.
        :param offset: Offset needed to return a specific subset of documents.
        :param owner_id: ID of the user or community that owns the documents. Use a negative value to designate a community ID.
        :param return_tags:
        :param type:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.get", params)
        model = DocsGetResponse
        return model(**response).response

    async def get_by_id(
        self,
        docs: typing.List[str],
        return_tags: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> typing.List[DocsDoc]:
        """Method `docs.getById()`

        :param docs: Document IDs. Example: , "66748_91488,66748_91455",
        :param return_tags:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.getById", params)
        model = DocsGetByIdResponse
        return model(**response).response

    async def get_messages_upload_server(
        self,
        peer_id: typing.Optional[int] = None,
        type: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> "BaseUploadServer":
        """Method `docs.getMessagesUploadServer()`

        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'Chat ID', e.g. '2000000001'. For community: '- Community ID', e.g. '-12345'. "
        :param type: Document type.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.getMessagesUploadServer", params)
        model = DocsGetUploadServerResponse
        return model(**response).response

    async def get_types(
        self,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> DocsGetTypesResponseModel:
        """Method `docs.getTypes()`

        :param owner_id: ID of the user or community that owns the documents. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.getTypes", params)
        model = DocsGetTypesResponse
        return model(**response).response

    async def get_upload_server(
        self,
        group_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> "BaseUploadServer":
        """Method `docs.getUploadServer()`

        :param group_id: Community ID (if the document will be uploaded to the community).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.getUploadServer", params)
        model = DocsGetUploadServerResponse
        return model(**response).response

    async def get_wall_upload_server(
        self,
        group_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> "BaseUploadServer":
        """Method `docs.getWallUploadServer()`

        :param group_id: Community ID (if the document will be uploaded to the community).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.getWallUploadServer", params)
        model = BaseGetUploadServerResponse
        return model(**response).response

    async def restore(
        self,
        doc_id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `docs.restore()`

        :param doc_id:
        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.restore", params)
        model = BaseOkResponse
        return model(**response).response

    async def save(
        self,
        file: str,
        return_tags: typing.Optional[bool] = None,
        tags: typing.Optional[str] = None,
        title: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> DocsSaveResponseModel:
        """Method `docs.save()`

        :param file: This parameter is returned when the file is [vk.com/dev/upload_files_2|uploaded to the server].
        :param return_tags:
        :param tags: Document tags.
        :param title: Document title.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.save", params)
        model = DocsSaveResponse
        return model(**response).response

    async def search(
        self,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        q: typing.Optional[str] = None,
        return_tags: typing.Optional[bool] = None,
        search_own: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> DocsSearchResponseModel:
        """Method `docs.search()`

        :param count: Number of results to return.
        :param offset: Offset needed to return a specific subset of results.
        :param q: Search query string.
        :param return_tags:
        :param search_own:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.search", params)
        model = DocsSearchResponse
        return model(**response).response


__all__ = ("DocsCategory",)



from vkbottle_types.base_model import Field
from vkbottle_types.objects import StatusStatus
from vkbottle_types.responses.base_response import BaseResponse


class StatusGetResponse(BaseResponse):
    response: "StatusStatus" = Field()



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    GroupsAddress,
    GroupsCallbackServer,
    GroupsCallbackSettings,
    GroupsGroupAccess,
    GroupsGroupAgeLimits,
    GroupsGroupAudio,
    GroupsGroupCategory,
    GroupsGroupCategoryFull,
    GroupsGroupDocs,
    GroupsGroupFull,
    GroupsGroupFullSection,
    GroupsGroupPhotos,
    GroupsGroupPublicCategoryList,
    GroupsGroupSuggestedPrivacy,
    GroupsGroupTag,
    GroupsGroupTopics,
    GroupsGroupVideo,
    GroupsGroupWall,
    GroupsGroupWiki,
    GroupsLinksItem,
    GroupsLongPollServer,
    GroupsLongPollSettings,
    GroupsMemberRole,
    GroupsMemberStatus,
    GroupsMemberStatusFull,
    GroupsOnlineStatusType,
    GroupsOwnerXtrBanInfo,
    GroupsProfileItem,
    GroupsSectionsListItem,
    GroupsSettingsTwitter,
    GroupsSubjectItem,
    GroupsTokenPermissionSetting,
    GroupsUserXtrRole,
    UsersUserFull,
    UsersUserMin,
)
from vkbottle_types.responses.base_response import BaseResponse


class GroupsAddAddressResponse(BaseResponse):
    response: "GroupsAddress" = Field()


class GroupsAddCallbackServerResponseModel(BaseModel):
    server_id: int = Field()


class GroupsAddCallbackServerResponse(BaseResponse):
    response: "GroupsAddCallbackServerResponseModel" = Field()


class GroupsAddLinkResponse(BaseResponse):
    response: "GroupsLinksItem" = Field()


class GroupsCreateResponse(BaseResponse):
    response: "GroupsGroupFull" = Field()


class GroupsEditAddressResponse(BaseResponse):
    response: "GroupsAddress" = Field()


class GroupsGetAddressesResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["GroupsAddress"] = Field()


class GroupsGetAddressesResponse(BaseResponse):
    response: "GroupsGetAddressesResponseModel" = Field()


class GroupsGetBannedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["GroupsOwnerXtrBanInfo"] = Field()


class GroupsGetBannedResponse(BaseResponse):
    response: "GroupsGetBannedResponseModel" = Field()


class GroupsGetByIdObjectResponseModel(BaseModel):
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )
    profiles: typing.Optional[typing.List["GroupsProfileItem"]] = Field(
        default=None,
    )


class GroupsGetByIdObjectResponse(BaseResponse):
    response: "GroupsGetByIdObjectResponseModel" = Field()


class GroupsGetCallbackConfirmationCodeResponseModel(BaseModel):
    code: str = Field()


class GroupsGetCallbackConfirmationCodeResponse(BaseResponse):
    response: "GroupsGetCallbackConfirmationCodeResponseModel" = Field()


class GroupsGetCallbackServersResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["GroupsCallbackServer"] = Field()


class GroupsGetCallbackServersResponse(BaseResponse):
    response: "GroupsGetCallbackServersResponseModel" = Field()


class GroupsGetCallbackSettingsResponse(BaseResponse):
    response: "GroupsCallbackSettings" = Field()


class GroupsGetCatalogInfoExtendedResponseModel(BaseModel):
    enabled: bool = Field()
    categories: typing.Optional[typing.List["GroupsGroupCategoryFull"]] = Field(
        default=None,
    )


class GroupsGetCatalogInfoExtendedResponse(BaseResponse):
    response: "GroupsGetCatalogInfoExtendedResponseModel" = Field()


class GroupsGetCatalogInfoResponseModel(BaseModel):
    enabled: bool = Field()
    categories: typing.Optional[typing.List["GroupsGroupCategory"]] = Field(
        default=None,
    )


class GroupsGetCatalogInfoResponse(BaseResponse):
    response: "GroupsGetCatalogInfoResponseModel" = Field()


class GroupsGetInvitedUsersResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["UsersUserFull"] = Field()


class GroupsGetInvitedUsersResponse(BaseResponse):
    response: "GroupsGetInvitedUsersResponseModel" = Field()


class GroupsGetInvitesExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["GroupsGroupFull"] = Field()
    profiles: typing.List["UsersUserMin"] = Field()
    groups: typing.List["GroupsGroupFull"] = Field()


class GroupsGetInvitesExtendedResponse(BaseResponse):
    response: "GroupsGetInvitesExtendedResponseModel" = Field()


class GroupsGetInvitesResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["GroupsGroupFull"] = Field()


class GroupsGetInvitesResponse(BaseResponse):
    response: "GroupsGetInvitesResponseModel" = Field()


class GroupsGetLongPollServerResponse(BaseResponse):
    response: "GroupsLongPollServer" = Field()


class GroupsGetLongPollSettingsResponse(BaseResponse):
    response: "GroupsLongPollSettings" = Field()


class GroupsGetMembersFieldsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["GroupsUserXtrRole"] = Field()
    next_from: typing.Optional[str] = Field(
        default=None,
    )


class GroupsGetMembersFieldsResponse(BaseResponse):
    response: "GroupsGetMembersFieldsResponseModel" = Field()


class GroupsGetMembersFilterResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["GroupsMemberRole"] = Field()
    next_from: typing.Optional[str] = Field(
        default=None,
    )


class GroupsGetMembersFilterResponse(BaseResponse):
    response: "GroupsGetMembersFilterResponseModel" = Field()


class GroupsGetMembersResponseModel(BaseModel):
    count: int = Field()
    items: typing.List[int] = Field()
    next_from: typing.Optional[str] = Field(
        default=None,
    )


class GroupsGetMembersResponse(BaseResponse):
    response: "GroupsGetMembersResponseModel" = Field()


class GroupsGetOnlineStatusResponseModel(BaseModel):
    status: "GroupsOnlineStatusType" = Field()
    minutes: typing.Optional[int] = Field(
        default=None,
    )


class GroupsGetOnlineStatusResponse(BaseResponse):
    response: "GroupsGetOnlineStatusResponseModel" = Field()


class GroupsGetRequestsFieldsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["UsersUserFull"] = Field()


class GroupsGetRequestsFieldsResponse(BaseResponse):
    response: "GroupsGetRequestsFieldsResponseModel" = Field()


class GroupsGetRequestsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List[int] = Field()


class GroupsGetRequestsResponse(BaseResponse):
    response: "GroupsGetRequestsResponseModel" = Field()


class GroupsGetSettingsResponseModel(BaseModel):
    audio: "GroupsGroupAudio" = Field()
    articles: int = Field()
    city_id: int = Field()
    city_name: str = Field()
    description: str = Field()
    docs: "GroupsGroupDocs" = Field()
    obscene_filter: bool = Field()
    obscene_stopwords: bool = Field()
    obscene_words: typing.List[str] = Field()
    toxic_filter: bool = Field()
    disable_replies_from_groups: bool = Field()
    photos: "GroupsGroupPhotos" = Field()
    title: str = Field()
    topics: "GroupsGroupTopics" = Field()
    video: "GroupsGroupVideo" = Field()
    wall: "GroupsGroupWall" = Field()
    wiki: "GroupsGroupWiki" = Field()
    access: typing.Optional["GroupsGroupAccess"] = Field(
        default=None,
    )
    address: typing.Optional[str] = Field(
        default=None,
    )
    recognize_photo: typing.Optional[int] = Field(
        default=None,
    )
    contacts: typing.Optional[bool] = Field(
        default=None,
    )
    links: typing.Optional[bool] = Field(
        default=None,
    )
    sections_list: typing.Optional[typing.List["GroupsSectionsListItem"]] = Field(
        default=None,
    )
    main_section: typing.Optional["GroupsGroupFullSection"] = Field(
        default=None,
    )
    secondary_section: typing.Optional["GroupsGroupFullSection"] = Field(
        default=None,
    )
    age_limits: typing.Optional["GroupsGroupAgeLimits"] = Field(
        default=None,
    )
    events: typing.Optional[bool] = Field(
        default=None,
    )
    addresses: typing.Optional[bool] = Field(
        default=None,
    )
    bots_capabilities: typing.Optional[bool] = Field(
        default=None,
    )
    bots_start_button: typing.Optional[bool] = Field(
        default=None,
    )
    bots_add_to_chat: typing.Optional[bool] = Field(
        default=None,
    )
    event_group_id: typing.Optional[int] = Field(
        default=None,
    )
    public_category: typing.Optional[int] = Field(
        default=None,
    )
    public_category_list: typing.Optional[typing.List["GroupsGroupPublicCategoryList"]] = Field(
        default=None,
    )
    public_date: typing.Optional[str] = Field(
        default=None,
    )
    public_date_label: typing.Optional[str] = Field(
        default=None,
    )
    public_subcategory: typing.Optional[int] = Field(
        default=None,
    )
    rss: typing.Optional[str] = Field(
        default=None,
    )
    start_date: typing.Optional[int] = Field(
        default=None,
    )
    finish_date: typing.Optional[int] = Field(
        default=None,
    )
    subject: typing.Optional[int] = Field(
        default=None,
    )
    subject_list: typing.Optional[typing.List["GroupsSubjectItem"]] = Field(
        default=None,
    )
    suggested_privacy: typing.Optional["GroupsGroupSuggestedPrivacy"] = Field(
        default=None,
    )
    twitter: typing.Optional["GroupsSettingsTwitter"] = Field(
        default=None,
    )
    website: typing.Optional[str] = Field(
        default=None,
    )
    phone: typing.Optional[str] = Field(
        default=None,
    )
    email: typing.Optional[str] = Field(
        default=None,
    )


class GroupsGetSettingsResponse(BaseResponse):
    response: "GroupsGetSettingsResponseModel" = Field()


class GroupsGetTagListResponse(BaseResponse):
    response: typing.List["GroupsGroupTag"] = Field()


class GroupsGetTokenPermissionsResponseModel(BaseModel):
    mask: int = Field()
    permissions: typing.List["GroupsTokenPermissionSetting"] = Field()


class GroupsGetTokenPermissionsResponse(BaseResponse):
    response: "GroupsGetTokenPermissionsResponseModel" = Field()


class GroupsGetObjectExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["GroupsGroupFull"] = Field()


class GroupsGetObjectExtendedResponse(BaseResponse):
    response: "GroupsGetObjectExtendedResponseModel" = Field()


class GroupsGetResponseModel(BaseModel):
    count: int = Field()
    items: typing.List[int] = Field()


class GroupsGetResponse(BaseResponse):
    response: "GroupsGetResponseModel" = Field()


class GroupsInviteUserIdsListResponseModel(BaseModel):
    invites_send_count: int = Field()


class GroupsInviteUserIdsListResponse(BaseResponse):
    response: "GroupsInviteUserIdsListResponseModel" = Field()


class GroupsIsMemberExtendedResponseModel(BaseModel):
    member: bool = Field()
    invitation: typing.Optional[bool] = Field(
        default=None,
    )
    can_invite: typing.Optional[bool] = Field(
        default=None,
    )
    can_recall: typing.Optional[bool] = Field(
        default=None,
    )
    request: typing.Optional[bool] = Field(
        default=None,
    )


class GroupsIsMemberExtendedResponse(BaseResponse):
    response: "GroupsIsMemberExtendedResponseModel" = Field()


class GroupsIsMemberUserIdsExtendedResponse(BaseResponse):
    response: typing.List["GroupsMemberStatusFull"] = Field()


class GroupsIsMemberUserIdsResponse(BaseResponse):
    response: typing.List["GroupsMemberStatus"] = Field()


class GroupsSearchResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["GroupsGroupFull"] = Field()


class GroupsSearchResponse(BaseResponse):
    response: "GroupsSearchResponseModel" = Field()



import typing

from vkbottle_types.base_model import Field
from vkbottle_types.objects import (
    SecureGiveEventStickerItem,
    SecureLevel,
    SecureSetCounterItem,
    SecureSmsNotification,
    SecureTokenChecked,
    SecureTransaction,
)
from vkbottle_types.responses.base_response import BaseResponse


class SecureCheckTokenResponse(BaseResponse):
    response: "SecureTokenChecked" = Field()


class SecureGetAppBalanceResponse(BaseResponse):
    response: int = Field()


class SecureGetSMSHistoryResponse(BaseResponse):
    response: typing.List["SecureSmsNotification"] = Field()


class SecureGetTransactionsHistoryResponse(BaseResponse):
    response: typing.List["SecureTransaction"] = Field()


class SecureGetUserLevelResponse(BaseResponse):
    response: typing.List["SecureLevel"] = Field()


class SecureGiveEventStickerResponse(BaseResponse):
    response: typing.List["SecureGiveEventStickerItem"] = Field()


class SecureSendNotificationResponse(BaseResponse):
    response: typing.List[int] = Field()


class SecureSetCounterArrayResponse(BaseResponse):
    response: typing.List["SecureSetCounterItem"] = Field()



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import OrdersAmount, OrdersOrder, OrdersSubscription
from vkbottle_types.responses.base_response import BaseResponse


class OrdersChangeStateResponse(BaseResponse):
    response: str = Field()


class OrdersGetAmountResponse(BaseResponse):
    response: typing.List["OrdersAmount"] = Field()


class OrdersGetByIdResponse(BaseResponse):
    response: typing.List["OrdersOrder"] = Field()


class OrdersGetUserSubscriptionByIdResponse(BaseResponse):
    response: "OrdersSubscription" = Field()


class OrdersGetUserSubscriptionsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["OrdersSubscription"] = Field()


class OrdersGetUserSubscriptionsResponse(BaseResponse):
    response: "OrdersGetUserSubscriptionsResponseModel" = Field()


class OrdersGetResponse(BaseResponse):
    response: typing.List["OrdersOrder"] = Field()



from typing import Union

from .bot_typings import GroupTypes
from .enums import GroupEventType, UserEventType
from .user_typings import UserTypes

Event = Union[UserEventType, GroupEventType]


__all__ = ("GroupTypes", "GroupEventType", "UserEventType", "UserTypes", "Event")



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    BaseUploadServer,
    DocsDoc,
    DocsDocAttachmentType,
    DocsDocTypes,
    MessagesAudioMessage,
    MessagesGraffiti,
)
from vkbottle_types.responses.base_response import BaseResponse


class DocsAddResponse(BaseResponse):
    response: int = Field()


class DocsDocUploadResponseModel(BaseModel):
    file: typing.Optional[str] = Field(
        default=None,
    )


class DocsDocUploadResponse(BaseResponse):
    response: "DocsDocUploadResponseModel" = Field()


class DocsGetByIdResponse(BaseResponse):
    response: typing.List["DocsDoc"] = Field()


class DocsGetTypesResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["DocsDocTypes"] = Field()


class DocsGetTypesResponse(BaseResponse):
    response: "DocsGetTypesResponseModel" = Field()


class DocsGetUploadServerResponse(BaseResponse):
    response: "BaseUploadServer" = Field()


class DocsGetResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["DocsDoc"] = Field()


class DocsGetResponse(BaseResponse):
    response: "DocsGetResponseModel" = Field()


class DocsSaveResponseModel(BaseModel):
    type: typing.Optional["DocsDocAttachmentType"] = Field(
        default=None,
    )
    audio_message: typing.Optional["MessagesAudioMessage"] = Field(
        default=None,
    )
    doc: typing.Optional["DocsDoc"] = Field(
        default=None,
    )
    graffiti: typing.Optional["MessagesGraffiti"] = Field(
        default=None,
    )


class DocsSaveResponse(BaseResponse):
    response: "DocsSaveResponseModel" = Field()


class DocsSearchResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["DocsDoc"] = Field()


class DocsSearchResponse(BaseResponse):
    response: "DocsSearchResponseModel" = Field()



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.search import *  # noqa: F401,F403  # type: ignore


class SearchCategory(BaseCategory):
    async def get_hints(
        self,
        fields: typing.Optional[typing.List[str]] = None,
        filters: typing.Optional[typing.List[str]] = None,
        limit: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        q: typing.Optional[str] = None,
        search_global: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> SearchGetHintsResponseModel:
        """Method `search.getHints()`

        :param fields:
        :param filters:
        :param limit: Maximum number of results to return.
        :param offset: Offset for querying specific result subset
        :param q: Search query string.
        :param search_global:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("search.getHints", params)
        model = SearchGetHintsResponse
        return model(**response).response


__all__ = ("SearchCategory",)
